==> flutter_bridge_webview-0.1.10.tar.gz: android/src/main/java/com/microduino/flutter_js_bridge/FlutterBridgeWebviewPlugin.java <==
package com.microduino.flutter_js_bridge;

import android.app.Activity;
import android.content.Context;
import android.content.Intent;
import android.graphics.Point;
import android.os.Build;
import android.util.Log;
import android.view.Display;
import android.view.View;
import android.view.ViewGroup;
import android.webkit.CookieManager;
import android.webkit.GeolocationPermissions;
import android.webkit.ValueCallback;
import android.webkit.WebChromeClient;
import android.webkit.WebSettings;
import android.webkit.WebStorage;
import android.widget.FrameLayout;

import com.github.lzyzsd.jsbridge.BridgeHandler;
import com.github.lzyzsd.jsbridge.BridgeWebView;
import com.github.lzyzsd.jsbridge.CallBackFunction;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.plugin.common.PluginRegistry;

/**
 * FlutterBridgeWebviewPlugin
 */
public class FlutterBridgeWebviewPlugin implements MethodChannel.MethodCallHandler, PluginRegistry.ActivityResultListener {

    private final String tag = "FlutterBridgeWebviewPlugin";
    private Activity activity;
    private BridgeWebView webView;
    boolean closed = false;
    private static MethodChannel methodChannel;
    private FlutterBridgeWebViewClient webViewClient;

    /**
     * Plugin registration.
     */
    public static void registerWith(PluginRegistry.Registrar registrar) {
        methodChannel = new MethodChannel(registrar.messenger(), "com.microduino.flutter/bridgewebview");
        final FlutterBridgeWebviewPlugin instance = new FlutterBridgeWebviewPlugin(registrar.activity());
        registrar.addActivityResultListener(instance);
        methodChannel.setMethodCallHandler(instance);
    }

    private FlutterBridgeWebviewPlugin(Activity activity) {
        this.activity = activity;
    }

    @Override
    public void onMethodCall(MethodCall methodCall, MethodChannel.Result result) {
        switch (methodCall.method) {
            case "launch":
                openUrl(methodCall, result);
                break;
            case "loadUrl":
                loadUrl(methodCall, result);
                break;
            case "resize":
                resize(methodCall, result);
                break;
            case "close":
                close(methodCall, result);
                break;
            case "canGoBack":
                canGoBack(methodCall, result);
                break;
            case "canGoForward":
                canGoForward(methodCall, result);
                break;
            case "goBack":
                goBack(methodCall, result);
                break;
            case "goForward":
                goForward(methodCall, result);
                break;
            case "reload":
                reload(methodCall, result);
                break;
            case "currentUrl":
                currentUrl(methodCall, result);
                break;
            case "callHandler":
                callHandler(methodCall, result);
                break;
            case "clearCache":
                clearCache(result);
                break;
            case "hide":
                hide(result);
                break;
            case "show":
                show(result);
                break;
            default:
                result.notImplemented();
        }
    }

    private void openUrl(MethodCall call, MethodChannel.Result result) {
        boolean hidden = call.argument("hidden");
        String url = call.argument("url");
        String userAgent = call.argument("userAgent");
        boolean withJavascript = call.argument("withJavascript");
        boolean clearCache = call.argument("clearCache");
        boolean clearCookies = call.argument("clearCookies");
        boolean withZoom = call.argument("withZoom");
        boolean withLocalStorage = call.argument("withLocalStorage");
        boolean appCacheEnabled = call.argument("appCacheEnabled");
        Map<String, String> headers = call.argument("headers");
        boolean scrollBar = call.argument("scrollBar");
        boolean allowFileURLs = call.argument("allowFileURLs");
        boolean geolocationEnabled = call.argument("geolocationEnabled");
        List<String> bridgeChannelNames = call.argument("bridgeChannels");

        Log.e("guorui", "----> openUrl webView === " + webView);
        Log.e("guorui", "----> openUrl closed === " + closed);

        if (webView == null || closed) {
            webView = new BridgeWebView(activity);

            Log.e("guorui", "----> withLocalStorage === " + withLocalStorage);
            webView.getSettings().setDomStorageEnabled(withLocalStorage);

            // webView.getSettings().setJavaScriptEnabled(withJavascript);
            // webView.getSettings().setBuiltInZoomControls(withZoom);
            // webView.getSettings().setSupportZoom(withZoom);
            // webView.getSettings().setAppCacheEnabled(appCacheEnabled);
            // webView.getSettings().setAllowFileAccessFromFileURLs(allowFileURLs);
            // webView.getSettings().setAllowUniversalAccessFromFileURLs(allowFileURLs);

            // webViewClient = new FlutterBridgeWebViewClient(webView, methodChannel);
            // webView.setWebViewClient(webViewClient);
        }

        Log.e("guorui", "----> bridgeChannelNames === " + bridgeChannelNames);

        if (bridgeChannelNames != null && bridgeChannelNames.size() > 0) {
            registerBridgeChannelNames(bridgeChannelNames);
        }
        FrameLayout.LayoutParams params = buildLayoutParams(call);

        activity.addContentView(webView, params);
        /*if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.LOLLIPOP) {
            webView.getSettings().setMixedContentMode(WebSettings.MIXED_CONTENT_COMPATIBILITY_MODE);
        }

        if (clearCache) {
            webView.clearCache(true);
            webView.clearFormData();
            WebStorage.getInstance().deleteAllData();
        }*/

        if (hidden) {
            webView.setVisibility(View.GONE);
        } else{
            webView.setVisibility(View.VISIBLE);
        }

        /*if (clearCookies) {
            if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.LOLLIPOP) {
                CookieManager.getInstance().removeAllCookies(new ValueCallback<Boolean>() {
                    @Override
                    public void onReceiveValue(Boolean aBoolean) {}
                });
            } else {
                CookieManager.getInstance().removeAllCookie();
            }
        }

        if (userAgent != null) {
            webView.getSettings().setUserAgentString(userAgent);
        }

        if (!scrollBar) {
            webView.setVerticalScrollBarEnabled(false);
        }*/

        if (headers != null) {
            webView.loadUrl(url, headers);
        } else {
            webView.loadUrl(url);
        }

        result.success(null);
    }

    private FrameLayout.LayoutParams buildLayoutParams(MethodCall call) {
        Map<String, Number> rc = call.argument("rect");
        FrameLayout.LayoutParams params;
        if (rc != null) {
            params = new FrameLayout.LayoutParams(
                    dp2px(activity, rc.get("width").intValue()),
                    dp2px(activity, rc.get("height").intValue()));
            params.setMargins(
                    dp2px(activity, rc.get("left").intValue()),
                    dp2px(activity, rc.get("top").intValue()),
                    0, 0);
        } else {
            Display display = activity.getWindowManager().getDefaultDisplay();
            Point size = new Point();
            display.getSize(size);
            int width = size.x;
            int height = size.y;
            params = new FrameLayout.LayoutParams(width, height);
        }

        return params;
    }

    void close(MethodCall call, MethodChannel.Result result) {
        if (webView != null) {
            ViewGroup vg = (ViewGroup) (webView.getParent());
            vg.removeView(webView);
        }
        webView = null;
        if (result != null) {
            result.success(null);
        }

        closed = true;
        methodChannel.invokeMethod("onDestroy", null);
    }

    void close() {
        close(null, null);
    }

    private void loadUrl(MethodCall methodCall, MethodChannel.Result result) {
        if (webView != null) {
            String url = (String) methodCall.arguments;
            webView.loadUrl(url);
        }
        result.success(null);
    }

    private void resize(MethodCall call, final MethodChannel.Result result) {
        if (webView != null) {
            FrameLayout.LayoutParams params = buildLayoutParams(call);
            webView.setLayoutParams(params);
        }
        result.success(null);
    }

    private void canGoBack(MethodCall methodCall, MethodChannel.Result result) {
        result.success(webView.canGoBack());
    }

    private void canGoForward(MethodCall methodCall, MethodChannel.Result result) {
        result.success(webView.canGoForward());
    }

    private void goBack(MethodCall methodCall, MethodChannel.Result result) {
        if (webView.canGoBack()) {
            webView.goBack();
        }
        result.success(null);
    }

    private void goForward(MethodCall methodCall, MethodChannel.Result result) {
        if (webView.canGoForward()) {
            webView.goForward();
        }
        result.success(null);
    }

    private void reload(MethodCall methodCall, MethodChannel.Result result) {
        webView.reload();
        result.success(null);
    }

    private void currentUrl(MethodCall methodCall, MethodChannel.Result result) {
        result.success(webView.getUrl());
    }

    private void registerBridgeChannelNames(List<String> channelNames) {
        for (final String channelName : channelNames) {
            webView.registerHandler(channelName, new BridgeHandler() {
                @Override
                public void handler(String data, final CallBackFunction function) {
                    Map<String, Object> args = new HashMap<>();
                    args.put("method", channelName);
                    methodChannel.invokeMethod("onRegisterHandlerCallback", args, new MethodChannel.Result() {
                        @Override
                        public void success(Object var1) {
                            function.onCallBack((String) var1);
                        }

                        @Override
                        public void error(String var1, String var2, Object var3) {}

                        @Override
                        public void notImplemented() {}
                    });
                }
            });
        }
    }

    private void callHandler(MethodCall methodCall, MethodChannel.Result result) {
        final Map<String, Object> method = (Map<String, Object>) methodCall.arguments;
        final String name = (String) method.get("name");
        final String data = (String) method.get("data");
        Log.e(tag, "----> callHandler [" + name + "(" + data + ")]");
        webView.callHandler(name, data, new CallBackFunction() {
            @Override
            public void onCallBack(String data) {
                Map<String, Object> args = new HashMap<>();
                args.put("method", name);
                methodChannel.invokeMethod("onCallHandlerCallBack", args);
            }
        });
        result.success(null);
    }

    private void clearCache(MethodChannel.Result result) {
        webView.clearCache(true);
        WebStorage.getInstance().deleteAllData();
        result.success(null);
    }

    private void hide(MethodChannel.Result result) {
        if (webView != null) {
            webView.setVisibility(View.GONE);
        }
        result.success(null);
    }

    private void show(MethodChannel.Result result) {
        if (webView != null) {
            webView.setVisibility(View.VISIBLE);
        }
        result.success(null);
    }

    private int dp2px(Context context, float dp) {
        final float scale = context.getResources().getDisplayMetrics().density;
        return (int) (dp * scale + 0.5f);
    }

    @Override
    public boolean onActivityResult(int i, int i1, Intent intent) {
        return false;
    }
}

==> flutter_bridge_webview-0.1.11.tar.gz: android/src/main/java/com/microduino/flutter_js_bridge/FlutterBridgeWebviewPlugin.java <==
package com.microduino.flutter_js_bridge;

import android.app.Activity;
import android.content.Context;
import android.content.Intent;
import android.graphics.Point;
import android.os.Build;
import android.util.Log;
import android.view.Display;
import android.view.View;
import android.view.ViewGroup;
import android.webkit.CookieManager;
import android.webkit.GeolocationPermissions;
import android.webkit.ValueCallback;
import android.webkit.WebChromeClient;
import android.webkit.WebSettings;
import android.webkit.WebStorage;
import android.widget.FrameLayout;

import com.github.lzyzsd.jsbridge.BridgeHandler;
import com.github.lzyzsd.jsbridge.BridgeWebView;
import com.github.lzyzsd.jsbridge.CallBackFunction;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.plugin.common.PluginRegistry;

/**
 * FlutterBridgeWebviewPlugin
 */
public class FlutterBridgeWebviewPlugin implements MethodChannel.MethodCallHandler, PluginRegistry.ActivityResultListener {

    private final String tag = "FlutterBridgeWebviewPlugin";
    private Activity activity;
    private BridgeWebView webView;
    boolean closed = false;
    private static MethodChannel methodChannel;
    private FlutterBridgeWebViewClient webViewClient;

    /**
     * Plugin registration.
     */
    public static void registerWith(PluginRegistry.Registrar registrar) {
        methodChannel = new MethodChannel(registrar.messenger(), "com.microduino.flutter/bridgewebview");
        final FlutterBridgeWebviewPlugin instance = new FlutterBridgeWebviewPlugin(registrar.activity());
        registrar.addActivityResultListener(instance);
        methodChannel.setMethodCallHandler(instance);
    }

    private FlutterBridgeWebviewPlugin(Activity activity) {
        this.activity = activity;
    }

    @Override
    public void onMethodCall(MethodCall methodCall, MethodChannel.Result result) {
        switch (methodCall.method) {
            case "launch":
                openUrl(methodCall, result);
                break;
            case "loadUrl":
                loadUrl(methodCall, result);
                break;
            case "resize":
                resize(methodCall, result);
                break;
            case "close":
                close(methodCall, result);
                break;
            case "canGoBack":
                canGoBack(methodCall, result);
                break;
            case "canGoForward":
                canGoForward(methodCall, result);
                break;
            case "goBack":
                goBack(methodCall, result);
                break;
            case "goForward":
                goForward(methodCall, result);
                break;
            case "reload":
                reload(methodCall, result);
                break;
            case "currentUrl":
                currentUrl(methodCall, result);
                break;
            case "callHandler":
                callHandler(methodCall, result);
                break;
            case "clearCache":
                clearCache(result);
                break;
            case "hide":
                hide(result);
                break;
            case "show":
                show(result);
                break;
            default:
                result.notImplemented();
        }
    }

    private void openUrl(MethodCall call, MethodChannel.Result result) {
        boolean hidden = call.argument("hidden");
        String url = call.argument("url");
        String userAgent = call.argument("userAgent");
        boolean withJavascript = call.argument("withJavascript");
        boolean clearCache = call.argument("clearCache");
        boolean clearCookies = call.argument("clearCookies");
        boolean withZoom = call.argument("withZoom");
        boolean withLocalStorage = call.argument("withLocalStorage");
        boolean appCacheEnabled = call.argument("appCacheEnabled");
        Map<String, String> headers = call.argument("headers");
        boolean scrollBar = call.argument("scrollBar");
        boolean allowFileURLs = call.argument("allowFileURLs");
        boolean geolocationEnabled = call.argument("geolocationEnabled");
        List<String> bridgeChannelNames = call.argument("bridgeChannels");

        Log.e("guorui", "----> openUrl webView === " + webView);
        Log.e("guorui", "----> openUrl closed === " + closed);

        if (webView == null || closed) {
            webView = new BridgeWebView(activity);

            Log.e("guorui", "----> withLocalStorage === " + withLocalStorage);
            webView.getSettings().setDomStorageEnabled(withLocalStorage);

            // webView.getSettings().setJavaScriptEnabled(withJavascript);
            // webView.getSettings().setBuiltInZoomControls(withZoom);
            // webView.getSettings().setSupportZoom(withZoom);
            // webView.getSettings().setAppCacheEnabled(appCacheEnabled);
            // webView.getSettings().setAllowFileAccessFromFileURLs(allowFileURLs);
            // webView.getSettings().setAllowUniversalAccessFromFileURLs(allowFileURLs);

            webViewClient = new FlutterBridgeWebViewClient(webView, methodChannel);
            webView.setWebViewClient(webViewClient);
        }

        Log.e("guorui", "----> bridgeChannelNames === " + bridgeChannelNames);

        if (bridgeChannelNames != null && bridgeChannelNames.size() > 0) {
            registerBridgeChannelNames(bridgeChannelNames);
        }
        FrameLayout.LayoutParams params = buildLayoutParams(call);

        activity.addContentView(webView, params);
        /*if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.LOLLIPOP) {
            webView.getSettings().setMixedContentMode(WebSettings.MIXED_CONTENT_COMPATIBILITY_MODE);
        }

        if (clearCache) {
            webView.clearCache(true);
            webView.clearFormData();
            WebStorage.getInstance().deleteAllData();
        }*/

        if (hidden) {
            webView.setVisibility(View.GONE);
        } else{
            webView.setVisibility(View.VISIBLE);
        }

        /*if (clearCookies) {
            if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.LOLLIPOP) {
                CookieManager.getInstance().removeAllCookies(new ValueCallback<Boolean>() {
                    @Override
                    public void onReceiveValue(Boolean aBoolean) {}
                });
            } else {
                CookieManager.getInstance().removeAllCookie();
            }
        }

        if (userAgent != null) {
            webView.getSettings().setUserAgentString(userAgent);
        }

        if (!scrollBar) {
            webView.setVerticalScrollBarEnabled(false);
        }*/

        if (headers != null) {
            webView.loadUrl(url, headers);
        } else {
            webView.loadUrl(url);
        }

        result.success(null);
    }

    private FrameLayout.LayoutParams buildLayoutParams(MethodCall call) {
        Map<String, Number> rc = call.argument("rect");
        FrameLayout.LayoutParams params;
        if (rc != null) {
            params = new FrameLayout.LayoutParams(
                    dp2px(activity, rc.get("width").intValue()),
                    dp2px(activity, rc.get("height").intValue()));
            params.setMargins(
                    dp2px(activity, rc.get("left").intValue()),
                    dp2px(activity, rc.get("top").intValue()),
                    0, 0);
        } else {
            Display display = activity.getWindowManager().getDefaultDisplay();
            Point size = new Point();
            display.getSize(size);
            int width = size.x;
            int height = size.y;
            params = new FrameLayout.LayoutParams(width, height);
        }

        return params;
    }

    void close(MethodCall call, MethodChannel.Result result) {
        if (webView != null) {
            ViewGroup vg = (ViewGroup) (webView.getParent());
            vg.removeView(webView);
        }
        webView = null;
        if (result != null) {
            result.success(null);
        }

        closed = true;
        methodChannel.invokeMethod("onDestroy", null);
    }

    void close() {
        close(null, null);
    }

    private void loadUrl(MethodCall methodCall, MethodChannel.Result result) {
        if (webView != null) {
            String url = (String) methodCall.arguments;
            webView.loadUrl(url);
        }
        result.success(null);
    }

    private void resize(MethodCall call, final MethodChannel.Result result) {
        if (webView != null) {
            FrameLayout.LayoutParams params = buildLayoutParams(call);
            webView.setLayoutParams(params);
        }
        result.success(null);
    }

    private void canGoBack(MethodCall methodCall, MethodChannel.Result result) {
        result.success(webView.canGoBack());
    }

    private void canGoForward(MethodCall methodCall, MethodChannel.Result result) {
        result.success(webView.canGoForward());
    }

    private void goBack(MethodCall methodCall, MethodChannel.Result result) {
        if (webView.canGoBack()) {
            webView.goBack();
        }
        result.success(null);
    }

    private void goForward(MethodCall methodCall, MethodChannel.Result result) {
        if (webView.canGoForward()) {
            webView.goForward();
        }
        result.success(null);
    }

    private void reload(MethodCall methodCall, MethodChannel.Result result) {
        webView.reload();
        result.success(null);
    }

    private void currentUrl(MethodCall methodCall, MethodChannel.Result result) {
        result.success(webView.getUrl());
    }

    private void registerBridgeChannelNames(List<String> channelNames) {
        for (final String channelName : channelNames) {
            webView.registerHandler(channelName, new BridgeHandler() {
                @Override
                public void handler(String data, final CallBackFunction function) {
                    Map<String, Object> args = new HashMap<>();
                    args.put("method", channelName);
                    methodChannel.invokeMethod("onRegisterHandlerCallback", args, new MethodChannel.Result() {
                        @Override
                        public void success(Object var1) {
                            function.onCallBack((String) var1);
                        }

                        @Override
                        public void error(String var1, String var2, Object var3) {}

                        @Override
                        public void notImplemented() {}
                    });
                }
            });
        }
    }

    private void callHandler(MethodCall methodCall, MethodChannel.Result result) {
        final Map<String, Object> method = (Map<String, Object>) methodCall.arguments;
        final String name = (String) method.get("name");
        final String data = (String) method.get("data");
        Log.e(tag, "----> callHandler [" + name + "(" + data + ")]");
        webView.callHandler(name, data, new CallBackFunction() {
            @Override
            public void onCallBack(String data) {
                Map<String, Object> args = new HashMap<>();
                args.put("method", name);
                methodChannel.invokeMethod("onCallHandlerCallBack", args);
            }
        });
        result.success(null);
    }

    private void clearCache(MethodChannel.Result result) {
        webView.clearCache(true);
        WebStorage.getInstance().deleteAllData();
        result.success(null);
    }

    private void hide(MethodChannel.Result result) {
        if (webView != null) {
            webView.setVisibility(View.GONE);
        }
        result.success(null);
    }

    private void show(MethodChannel.Result result) {
        if (webView != null) {
            webView.setVisibility(View.VISIBLE);
        }
        result.success(null);
    }

    private int dp2px(Context context, float dp) {
        final float scale = context.getResources().getDisplayMetrics().density;
        return (int) (dp * scale + 0.5f);
    }

    @Override
    public boolean onActivityResult(int i, int i1, Intent intent) {
        return false;
    }
}
